@@ -4,8 +4,8 @@ from unittest import mock
 from unittest.mock import MagicMock
 
 from testfixtures import LogCapture
-from slack.web.slack_response import SlackResponse
-from slack import WebClient
+from slack_sdk.web.slack_response import SlackResponse
+from slack_sdk import WebClient
 
 import gokart.slack
 
@@ -23,7 +23,7 @@ def _slack_response(token, data):
 
 
 class TestSlackAPI(unittest.TestCase):
-    @mock.patch('gokart.slack.slack_api.slack.WebClient')
+    @mock.patch('gokart.slack.slack_api.slack_sdk.WebClient')
     def test_initialization_with_invalid_token(self, patch):
         def _conversations_list(params={}):
             return _slack_response(token='invalid', data={'ok': False, 'error': 'error_reason'})
@@ -34,10 +34,9 @@ class TestSlackAPI(unittest.TestCase):
 
         with LogCapture() as l:
             gokart.slack.SlackAPI(token='invalid', channel='test', to_user='test user')
-            l.check(('gokart.slack.slack_api', 'WARNING',
-                     'The job will start without slack notification: Channel test is not found in public channels.'))
+            l.check(('gokart.slack.slack_api', 'WARNING', 'The job will start without slack notification: Channel test is not found in public channels.'))
 
-    @mock.patch('gokart.slack.slack_api.slack.WebClient')
+    @mock.patch('gokart.slack.slack_api.slack_sdk.WebClient')
     def test_invalid_channel(self, patch):
         def _conversations_list(params={}):
             return _slack_response(token='valid',
@@ -58,12 +57,10 @@ class TestSlackAPI(unittest.TestCase):
 
         with LogCapture() as l:
             gokart.slack.SlackAPI(token='valid', channel='invalid_channel', to_user='test user')
-            l.check((
-                'gokart.slack.slack_api', 'WARNING',
-                'The job will start without slack notification: Channel invalid_channel is not found in public channels.'
-            ))
+            l.check(('gokart.slack.slack_api', 'WARNING',
+                     'The job will start without slack notification: Channel invalid_channel is not found in public channels.'))
 
-    @mock.patch('gokart.slack.slack_api.slack.WebClient')
+    @mock.patch('gokart.slack.slack_api.slack_sdk.WebClient')
     def test_send_snippet_with_invalid_token(self, patch):
         def _conversations_list(params={}):
             return _slack_response(token='valid',
@@ -90,11 +87,9 @@ class TestSlackAPI(unittest.TestCase):
         with LogCapture() as l:
             api = gokart.slack.SlackAPI(token='valid', channel='valid', to_user='test user')
             api.send_snippet(comment='test', title='title', content='content')
-            l.check(
-                ('gokart.slack.slack_api', 'WARNING',
-                 'Failed to send slack notification: Error while uploading file. The error reason is "error_reason".'))
+            l.check(('gokart.slack.slack_api', 'WARNING', 'Failed to send slack notification: Error while uploading file. The error reason is "error_reason".'))
 
-    @mock.patch('gokart.slack.slack_api.slack.WebClient')
+    @mock.patch('gokart.slack.slack_api.slack_sdk.WebClient')
     def test_send(self, patch):
         def _conversations_list(params={}):
             return _slack_response(token='valid',
