@@ -11,6 +11,7 @@ import gokart
 from gokart.parameter import TaskInstanceParameter, ListTaskInstanceParameter
 from gokart.file_processor import XmlFileProcessor
 from gokart.target import TargetOnKart, SingleFileTarget, ModelTarget
+from gokart.run_with_lock import RunWithLock
 
 
 class _DummyTask(gokart.TaskOnKart):
@@ -56,6 +57,32 @@ class _DummyTaskD(gokart.TaskOnKart):
     task_namespace = __name__
 
 
+class _DummyTaskWithLock(gokart.TaskOnKart):
+    task_namespace = __name__
+
+    @RunWithLock
+    def run(self):
+        pass
+
+
+class _DummyTaskWithLockMultipleOutput(gokart.TaskOnKart):
+    task_namespace = __name__
+
+    @RunWithLock
+    def run(self):
+        pass
+
+    def output(self):
+        return dict(dataA=self.make_target('fileA.pkl'), dataB=self.make_target('fileB.pkl'))
+
+
+class _DummyTaskWithoutLock(gokart.TaskOnKart):
+    task_namespace = __name__
+
+    def run(self):
+        pass
+
+
 class TaskTest(unittest.TestCase):
     def setUp(self):
         _DummyTask.clear_instance_cache()
@@ -257,6 +284,18 @@ class TaskTest(unittest.TestCase):
         task.dump(1)
         target.dump.assert_called_once()
 
+    def test_fail_on_empty_dump(self):
+        # do not fail
+        task = _DummyTask(fail_on_empty_dump=False)
+        target = MagicMock(spec=TargetOnKart)
+        task.output = MagicMock(return_value=target)
+        task.dump(pd.DataFrame())
+        target.dump.assert_called_once()
+
+        # fail
+        task = _DummyTask(fail_on_empty_dump=True)
+        self.assertRaises(AssertionError, lambda: task.dump(pd.DataFrame()))
+
     @patch('luigi.configuration.get_config')
     def test_add_configuration(self, mock_config: MagicMock):
         mock_config.return_value = {'_DummyTask': {'list_param': '["c", "d"]', 'param': '3', 'bool_param': 'True'}}
@@ -391,6 +430,39 @@ class TaskTest(unittest.TestCase):
             f'list_task_param=[{__name__}._SubTask({sub_task_id}), {__name__}._SubTask({sub_task_id})])'
         self.assertEqual(expected, str(task))
 
+    def test_run_with_lock_decorator(self):
+        task = _DummyTaskWithLock()
+
+        def _wrap(func):
+            return func
+
+        with patch('gokart.target.TargetOnKart.wrap_with_lock') as mock_obj:
+            mock_obj.side_effect = _wrap
+            task.run()
+            mock_obj.assert_called_once()
+
+    def test_run_with_lock_decorator_multiple_output(self):
+        task = _DummyTaskWithLockMultipleOutput()
+
+        def _wrap(func):
+            return func
+
+        with patch('gokart.target.TargetOnKart.wrap_with_lock') as mock_obj:
+            mock_obj.side_effect = _wrap
+            task.run()
+            self.assertEqual(mock_obj.call_count, 2)
+
+    def test_run_without_lock_decorator(self):
+        task = _DummyTaskWithoutLock()
+
+        def _wrap(func):
+            return func
+
+        with patch('gokart.target.TargetOnKart.wrap_with_lock') as mock_obj:
+            mock_obj.side_effect = _wrap
+            task.run()
+            mock_obj.assert_not_called()
+
 
 if __name__ == '__main__':
     unittest.main()
